***********
Customizing
***********

.. toctree::
  :maxdepth: 1
  :hidden:

  customsettings
  customize_templates
  customize_template_tags
  adding_pages
  target_fields
  customizing_data_processing
  create_broker
  customize_observations
  plotting_data
  permissions
  automation

Start here to learn how to customize the look and feel of your TOM or add new functionality.

:doc:`Custom Settings <customsettings>` - Settings available to the TOM Toolkit which you may want to
configure.

:doc:`Customizing TOM Templates <customize_templates>` - Learn how to override built in TOM templates to
change the look and feel of your TOM.

:doc:`Customizing Template Tag <customize_template_tags>` - Learn how to write your own template tags to display 
the data you need.

:doc:`Adding new Pages to your TOM <adding_pages>` - Learn how to add entirely new pages to your TOM,
displaying static html pages or dynamic database-driven content.

:doc:`Adding Custom Target Fields <target_fields>` - Learn how to add custom fields to your TOM Targets if the
defaults do not suffice.

:doc:`Adding Custom Data Processing <customizing_data_processing>` - Learn how you can process data into your
TOM from uploaded data products.

:doc:`Building a TOM Alert Broker <create_broker>` - Learn how to build an Alert Broker module to add new
sources of targets to your TOM.

:doc:`Changing Request Submission Behavior <customize_observations>` - Learn how to customize the LCO
Observation Module in order to add additional parameters to observation requests sent to the LCO Network.

:doc:`Creating Plots from TOM Data <plotting_data>` - Learn how to create plots using plot.ly and your TOM
data to display anywhere in your TOM.

:doc:`The Permissions System <permissions>` - Use the permissions system to limit access to targets in your
TOM.

:doc:`Automating Tasks <automation>` - Run commands automatically to keep your TOM working even when you
aren’t